@@ -1,3 +1,5 @@
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import logging
 import os
 import platform
@@ -5,21 +7,23 @@ import shlex
 import struct
 import subprocess
 import sys
-import tty
 
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
 
 if sys.platform == 'win32':
+    import msvcrt
     clear = 'cls'
 else:
+    import tty
+    import termios
     clear = 'clear'
 
 
+# Takes a string and adds it to the menu header along side
+# the app name.
 def app_header(*args, **kwargs):
-    # Takes a string and adds it to the menu header along side
-    # the app name.
     try:
         page = args[0]
     except IndexError:
@@ -40,9 +44,10 @@ def app_header(*args, **kwargs):
     os.system(clear)
     return add_style()
 
+
+# Gets a single character form standard input. Does not echo to the screen
 class _Getch:
-    """Gets a single character from standard input.  Does not echo to the
-screen."""
+
     def __init__(self):
         if sys.platform == 'win32':
             self.impl = _GetchWindows()
@@ -55,10 +60,14 @@ screen."""
 
 class _GetchUnix:
     def __init__(self):
-        import tty, sys
+        # Not sure if these imports are required here
+        # import tty, sys
+        pass
 
     def __call__(self):
-        import tty, termios
+        # NOt sure if these imports are required here
+        # import tty, termios
+        pass
         fd = sys.stdin.fileno()
         old_settings = termios.tcgetattr(fd)
         try:
@@ -71,17 +80,21 @@ class _GetchUnix:
 
 class _GetchWindows:
     def __init__(self):
-        import msvcrt
+        # Not sure if this import is required
+        # import msvcrt
+        pass
 
     def __call__(self):
-        import msvcrt
+        # Not sure if this import is required
+        # import msvcrt
         return msvcrt.getch()
 
 
+# Takes a string and retuns a string formatted
+# to the center of the terminal window.
 def format_msg(*args):
-    # Takes a string and retuns a string formatted
-    # to the center of the terminal window.
     window_size = get_terminal_size()[0]
+
     def fix():
         formatted = []
         finished = ['\n']
@@ -104,10 +117,10 @@ def format_msg(*args):
     return fix()
 
 
-def _options(*args):
-    # Takes a list of tuples(menu_name, call_back) adds menu numbers
-    # then prints menu to screen.
-    # Gets input from user, then returns the callback
+# Takes a list of tuples(menu_name, call_back) adds menu numbers
+# then prints menu to screen.
+# Gets input from user, then returns the callback
+def menu_options(*args):
     if len(args) != 1:
         return ""
     if not isinstance(args[0], list):
@@ -131,17 +144,17 @@ def _options(*args):
                 break
             else:
                 log.debug('Not an acceptable answer!')
-        return args[0][int(ans) -1][1]
+        return args[0][int(ans) - 1][1]
     return add_options()
 
 
+
+# get width and height of console
+# works on linux, os x, windows, cygwin(windows)
+# originally retrieved from:
+# http://stackoverflow.com/questions/
+# 566746/how-to-get-console-window-width-in-python
 def get_terminal_size():
-    """ getTerminalSize()
-     - get width and height of console
-     - works on linux, os x, windows, cygwin(windows)
-     originally retrieved from:
-     http://stackoverflow.com/questions/566746/how-to-get-console-window-width-in-python
-    """
     current_os = platform.system()
     tuple_xy = None
     if current_os == 'Windows':
@@ -192,7 +205,8 @@ def _get_terminal_size_linux():
     def ioctl_GWINSZ(fd):
         try:
             import fcntl
-            import termios
+            # Is this required
+            # import termios
             cr = struct.unpack('hh',
                                fcntl.ioctl(fd, termios.TIOCGWINSZ, '1234'))
             return cr
@@ -211,4 +225,4 @@ def _get_terminal_size_linux():
             cr = (os.environ['LINES'], os.environ['COLUMNS'])
         except:
             return None
-    return int(cr[1]), int(cr[0])
\ No newline at end of file
+    return int(cr[1]), int(cr[0])
