@@ -1,10 +1,10 @@
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import hashlib
 import os
 import sys
 from getpass import getpass
 
-user = os.path.expanduser('~')
-
 
 class SetupConfig(object):
     # If left None "Not_So_TUF" will be used
@@ -49,6 +49,24 @@ class SetupConfig(object):
     # Support for patch updates
     UPDATE_PATCHES = True
 
+    # Upload Setup
+    REMOTE_DIR = None
+    # SSH settings
+    # Path to ssh key of server
+    SSH_HOST = None
+    SSH_USERNAME = None
+    SSH_KEY_PATH = ''
+
+    # FTP settings
+    FTP_HOST = None
+    FTP_USERNAME = None
+    FTP_PASSWORD = None
+
+    # S3 settings
+    ACCESS_KEY_ID = None
+    SECRET_ACCESS_KEY = None
+    BUCKET_NAME = None
+
     def add_private_key_name(self, name):
         self.PRIVATE_KEY_NAME = name + '.pem'
 
@@ -113,6 +131,7 @@ def ask_yes_no(question, default='no'):
             print '\n\n\n\n'
 
 
+# Fixed path to work without quotes
 def path_fixer(path):
     # Removing ' & " in case user used them
     # for path with spaces
@@ -124,5 +143,24 @@ def path_fixer(path):
     return path.replace(' ', '\ ')
 
 
+# Explains itself
 def sha_digest(data):
     return hashlib.sha256(data).hexdigest()
+
+
+if getattr(sys, 'frozen', False):
+    # we are running in a |PyInstaller| bundle
+    _cwd = os.path.dirname(sys.argv[0])
+else:
+    # we are running in a normal Python environment
+    _cwd = os.getcwd()
+
+
+# Makes inputting directory more like shell
+def _directory_fixer(_dir):
+    if _dir == 'Current Working Directory':
+        _dir = _cwd
+    elif _dir.startswith('~'):
+        _dir = _dir[2:]
+        _dir = os.path.join(os.path.expanduser('~'), _dir)
+    return _dir
