@@ -1,11 +1,11 @@
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import json
 import logging
 import os
-import shutil
 import sys
 import urllib2
 
-from . import ClientException
 from .file_downloader import FileDownloader
 from .patcher import Patcher
 from .utils import ChDir, rsa_verify
@@ -51,10 +51,10 @@ class Client(object):
         self._setup()
 
     def update_check(self, name, version):
-        """Proxy method for :meth:`_patch_update` & :meth:`_full_update`. Will try to
-        patch binary if all check pass.  IE hash verified signature
-        verified.  If any check doesn't pass then falls back to full
-        update
+        """Proxy method for :meth:`_patch_update` & :meth:`_full_update`.
+        Will try to patch binary if all check pass.  IE hash verified
+        signature verified.  If any check doesn't pass then falls back to
+        full update
 
         Args:
             name (str): Name of file to update
@@ -108,7 +108,8 @@ class Client(object):
         # Just checking to see if the latest update is available to patch
         # If not we'll just do a full binary download
         if not os.path.exists(os.path.join(self.update_folder, filename)):
-            log.warning('{} got deleted. No base to start patching form'.format(filename))
+            log.warning('{} got deleted. No base to start patching '
+                        'form'.format(filename))
             return False
 
         p = Patcher(name, self.json_data, version, highest_version,
@@ -119,7 +120,6 @@ class Client(object):
         log.info('Was patch update successful? {}'.format(result))
         return result
 
-
     def _full_update(self, name, version):
         """Updates the binary by downloading full update
 
