@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
 
 import hashlib
 import time
 import urllib2
-import os
 import logging
 from io import BytesIO
 
