@@ -1,6 +1,5 @@
-# Big Thanks to FiloSottile for making this lib for us
-# All Files can be found in this gist
-# https://gist.github.com/FiloSottile/4340076
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 from binascii import hexlify
 
 import json
@@ -9,8 +8,8 @@ import os
 import rsa
 import shutil
 
-from not_so_tuf import KeyHandlerError
-from not_so_tuf.utils import FileCrypt
+from . import KeyHandlerError
+from .utils import FileCrypt
 
 log = logging.getLogger(__name__)
 
@@ -25,10 +24,6 @@ class KeyHandler(object):
     def __init__(self, app=None):
         if app:
             self.init_app(app)
-        self.update_data = None
-        self.privkey = None
-        self.pubkey = None
-        self.privkey_loaded = False
 
     def init_app(self, obj):
         """Sets up client with config values from obj
@@ -41,6 +36,7 @@ class KeyHandler(object):
         self.app_dir = obj.config.get('APP_DIR')
         self.app_name = obj.config.get('APP_NAME')
         self.data_dir = obj.config.get('DEV_DATA_DIR')
+        self.data_dir = os.path.join(self.data_dir, 'nst-data')
         self.private_key_name = obj.config.get('PRIVATE_KEY_NAME')
         if self.private_key_name is None:
             self.private_key_name = self.app_name + '.pem'
@@ -83,9 +79,11 @@ class KeyHandler(object):
         private = os.path.join(self.keys_dir, self.private_key_name)
         if os.path.exists(public) and os.path.exists(private):
             if overwrite is False:
+                log.info('Cannot overwrite old key files.')
+                log.debug('Pass overwrite=True to make_keys to overwrite')
                 return
             else:
-                log.debut('About to overwrite old keys')
+                log.warning('About to overwrite old keys')
         log.info('Writing keys to file')
         with open(private, 'w') as pri:
             pri.write(self.privkey)
@@ -138,11 +136,16 @@ class KeyHandler(object):
             raise KeyHandlerError(u"You don't have any keys",
                                   expected=True)
         privkey = os.path.join(self.keys_dir, self.private_key_name)
-        fc = FileCrypt(privkey)
-        fc.decrypt()
-        with open(privkey) as pk:
-            self.privkey = rsa.PrivateKey.load_pkcs1(pk.read())
-        fc.encrypt()
+        while 1:
+            try:
+                fc = FileCrypt(privkey)
+                fc.decrypt()
+                with open(privkey) as pk:
+                    self.privkey = rsa.PrivateKey.load_pkcs1(pk.read())
+                fc.encrypt()
+                break
+            except ValueError:
+                raw_input('Wrong password... Press enter to try again')
 
     def _load_update_data(self):
         """Loads version file
