@@ -1,4 +1,5 @@
-import hashlib
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import json
 import logging
 import os
@@ -11,8 +12,9 @@ try:
 except ImportError:
     PATCH_SUPPORT = False
 
-from not_so_tuf import PackageHandlerError
-from .utils import ChDir, ask_yes_no, _get_package_hashes
+from . import PackageHandlerError
+from .utils import (ChDir, ask_yes_no, _get_package_hashes,
+                    _remove_hidden_stuff_mac)
 
 log = logging.getLogger(__name__)
 
@@ -30,7 +32,7 @@ class PackageHandler(object):
         if app:
             self.init_app(app)
         else:
-            raise PackageHandlerError(u'Must pass an instance of Updater')
+            raise PackageHandlerError(u'Must pass an instance of NST')
 
     def init_app(self, obj):
         """Sets up client with config values from obj
@@ -52,10 +54,12 @@ class PackageHandler(object):
             log.debug('Looks like its not patch time.')
             self.patch_support = False
         self.data_dir = obj.config.get('DEV_DATA_DIR')
+        self.data_dir = os.path.join(self.data_dir, 'nst-data')
         self.update_url = obj.config.get('UPDATE_URL')
         self.files_dir = os.path.join(self.data_dir, 'files')
         self.deploy_dir = os.path.join(self.data_dir, 'deploy')
         self.new_dir = os.path.join(self.data_dir, 'new')
+
         self.json_data = None
         # seems to produce the best diffs.
         # ToDo: Run more tests to know for sure
@@ -308,7 +312,7 @@ class PackageHandler(object):
                 # someone tells me why this is a bad idea!
                 # if len(_files) < 2:
                     # return None
-                _files = self._remove_hidden_stuff_mac(_files)
+                _files = _remove_hidden_stuff_mac(_files)
                 if len(_files) < 1:
                     return None
                 highest_version = sorted(_files)[-1]
@@ -316,7 +320,7 @@ class PackageHandler(object):
                     return None
             version_dir = os.path.join(data_dir, highest_version)
             with ChDir(version_dir):
-                files = self._remove_hidden_stuff_mac(os.listdir(os.getcwd()))
+                files = _remove_hidden_stuff_mac(os.listdir(os.getcwd()))
                 if len(files) == 0:
                     return None
                 for f in files:
@@ -400,21 +404,3 @@ class PackageHandler(object):
         # What, thought it did something else? lol j/k
         reg = '-[0-9]+\.[0-9]+\.[0-9]+'
         return re.sub(reg, '', package_name)
-
-    def _remove_hidden_stuff_mac(self, files):
-        """Removes hidden files from file list
-
-        Args:
-            files (list): list of files
-
-        Returns:
-            (list) without .DS_Store and .AppleDouble
-        """
-        # Does what the name entails.
-        # ToDo: Implement a better way of handling this if there is one
-        # Any suggestions are warmly welcomed :)
-        new_list = []
-        for l in files:
-            if '.DS_Store' not in l and '.AppleDouble' not in l:
-                new_list.append(l)
-        return new_list
