@@ -1,8 +1,9 @@
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+
 import bsdiff4
 import hashlib
 import logging
 import os
-import sys
 
 from .file_downloader import FileDownloader
 from .utils import ChDir
@@ -52,15 +53,18 @@ class Patcher(object):
         # Check hash on installed binary to begin patching
         binary_check = self._verify_installed_binary()
         if binary_check is False:
+            log.warning('Binary check failed...')
             return False
         # Getting all required patch meta-data
         all_patches = self._get_all_patches(self.name)
         if all_patches is False:
+            log.warning('Cannot find all patches...')
             return False
 
         # Downloading and verify patches as i go
         download_check = self._download_verify_patches()
         if download_check is False:
+            log.warning('Patch check failed...')
             return False
         self._apply_patches_in_memory()
         self._write_update_to_disk()
