@@ -1,3 +1,4 @@
+import base64
 import getpass
 import hashlib
 import logging
@@ -6,9 +7,20 @@ import struct
 import sys
 
 import beefish
+import keyring
+import pbkdf2
 
 log = logging.getLogger(__name__)
 
+if getattr(sys, 'frozen', False):
+    log.debug('Running frozen')
+    # we are running in a |PyInstaller| bundle
+    _cwd = os.path.dirname(sys.argv[0])
+else:
+    log.debug('Running thawed out')
+    # we are running in a normal Python environment
+    _cwd = os.getcwd()
+
 
 class FileCrypt(object):
     """Smaller wrapper around beefish to make it easier to use
@@ -24,13 +36,19 @@ class FileCrypt(object):
         self.enc_filename = filename + '.enc'
         self.filenames = None
         self.password = None
+        self.tries = 0
+        self._get_password()
 
     def encrypt(self):
         """Encrypts file and deletes original"""
         if self.password is None:
             self._get_password()
-        beefish.encrypt_file(self.filename, self.enc_filename, self.password)
-        os.remove(self.filename)
+        try:
+            beefish.encrypt_file(self.filename, self.enc_filename,
+                                 self.password)
+            os.remove(self.filename)
+        except IOError:
+            log.warning('Cannot find original file')
         self._del_password()
 
     def decrypt(self):
@@ -39,7 +57,11 @@ class FileCrypt(object):
         """
         if self.password is None:
             self._get_password()
-        beefish.decrypt_file(self.enc_filename, self.filename, self.password)
+        try:
+            beefish.decrypt_file(self.enc_filename, self.filename,
+                                 self.password)
+        except IOError:
+            log.warning('Cannot find encrypted file.')
 
     def _del_password(self):
         """Deletes user password once its not needed.
@@ -50,7 +72,48 @@ class FileCrypt(object):
 
     def _get_password(self):
         """Gets user passwod without echoing to console"""
-        self.password = getpass.getpass('Enter passwword')
+        username = self.make_username()
+        app_name = 'NST-' + username
+        log.info('Looking for keyring password')
+        keyring_password = keyring.get_password(app_name, username)
+        if keyring_password is None:
+            log.warning('No keyring password found')
+            self._set_password()
+            keyring_password = keyring.get_password(app_name, username)
+        while self.tries < 2:
+            attempted_password = getpass.getpass('Enter login password')
+            if keyring_password == pbkdf2.crypt(attempted_password,
+                                                keyring_password):
+                self.password = keyring_password
+                break
+            else:
+                self.tries += 1
+                raw_input('\nInvalid Password.  Press enter to try again')
+        if self.password is None:
+            sys.exit(0)
+
+    def _set_password(self):
+        """Asks user for password twice, hashes password then sets password
+        in keyring
+        """
+        while 1:
+            print 'Create a new password.\n\n'
+            password1 = getpass.getpass('Enter password\n--> ')
+            password2 = getpass.getpass('Enter password again\n--> ')
+            if password1 == password2:
+                break
+            else:
+                msg = 'Passwords don\'t match.  Press enter to try again.'
+                raw_input(msg)
+        username = self.make_username()
+        app_name = 'NST-' + username
+        hashed = pbkdf2.crypt(password1)
+        keyring.set_password(app_name, username, hashed)
+
+    def make_username(self):
+        """Makes username by base54 encoding current working directory.
+        """
+        return base64.b64encode(_cwd)
 
 
 class ChDir(object):
@@ -111,6 +174,9 @@ def ask_yes_no(question, default='no'):
             print '\n\n\n\n'
 
 
+# Big Thanks to FiloSottile for making this lib for us
+# All Files can be found in this gist
+# https://gist.github.com/FiloSottile/4340076
 def rsa_verify(message, signature, key):
     def b(x):
         if sys.version_info[0] == 2:
@@ -155,8 +221,25 @@ def _get_package_hashes(filename):
         """
         log.info('Getting package hashes')
         with open(filename, 'rb') as f:
-            print filename
-            print os.getcwd()
             _hash = hashlib.md5(f.read()).hexdigest()
             log.debug('Hash for file {}: {}'.format(filename, _hash))
         return _hash
+
+
+def _remove_hidden_stuff_mac(files):
+        """Removes hidden files from file list
+
+        Args:
+            files (list): list of files
+
+        Returns:
+            (list) without .DS_Store and .AppleDouble
+        """
+        # Does what the name entails.
+        # ToDo: Implement a better way of handling this if there is one
+        # Any suggestions are warmly welcomed :)
+        new_list = []
+        for l in files:
+            if '.DS_Store' not in l and '.AppleDouble' not in l:
+                new_list.append(l)
+        return new_list
